==> dasu_3.02.jar: edu/northwestern/dasu/stats/UPnPSystemStats.java <==
/**
 * Dasu Project
 *
 * File:         DownloadStats.java
 * RCS:          $Id$
 * Description:  DownloadStats class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 10, 2007 at 1:39:15 PM
 * Language:     Java
 * Package:      edu.northwestern.news.stats
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2007, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.stats;

import edu.northwestern.dasu.measurement.UPnPBWStats;

/**
 * @author Mario Sanchez &lt;msanchez@u.northwestern.edu&gt;
 * 
 */

public class UPnPSystemStats implements Cloneable {
	
	public long timeRecorded;
	public long numberOfActiveConnections;
	public long totalBytesSent;
	public long totalBytesReceived;
	public long totalPacketsSent;
	public long totalPacketsReceived;
	public long uptime;

	public UPnPSystemStats() {
		
		
		if ( (UPnPBWStats.getInstance().getMostRecent() != null) ) {
			timeRecorded = UPnPBWStats.getInstance().getMostRecent().timeRecorded;
			numberOfActiveConnections = UPnPBWStats.getInstance().getMostRecent().numberOfActiveConnections;
			totalBytesSent = UPnPBWStats.getInstance().getMostRecent().totalBytesSent;
			totalBytesReceived = UPnPBWStats.getInstance().getMostRecent().totalBytesReceived;
			totalPacketsSent = UPnPBWStats.getInstance().getMostRecent().totalPacketsSent;
			totalPacketsReceived = UPnPBWStats.getInstance().getMostRecent().totalPacketsReceived;
			uptime = UPnPBWStats.getInstance().getMostRecent().uptime;
			
		}

	}
	
     public Object clone() {

    	 try {
              return super.clone();
          }
    	 catch( CloneNotSupportedException e ) {
              return null;
          }
      } 
     
     
     @Override
     public String toString() {
    	 
			return( this.timeRecorded + " " + this.numberOfActiveConnections + " " +
					this.totalBytesSent + " "  + this.totalBytesReceived + " " +
					this.totalPacketsSent + " " + this.totalPacketsReceived + " " + this.uptime);

     }
	
}

==> dasu_4.11.jar: edu/northwestern/dasu/stats/UPnPSystemStats.java <==
/**
 * Dasu Project
 *
 * File:         DownloadStats.java
 * RCS:          $Id$
 * Description:  DownloadStats class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 10, 2007 at 1:39:15 PM
 * Language:     Java
 * Package:      edu.northwestern.news.stats
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2007, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.stats;

import edu.northwestern.dasu.upnp.UPnPBWStats;

/**
 * @author Mario Sanchez &lt;msanchez@u.northwestern.edu&gt;
 * 
 */

public class UPnPSystemStats implements Cloneable {
	
	public long timeRecorded = -1;
	public long numberOfActiveConnections = -1;
	public long totalBytesSent = -1;
	public long totalBytesReceived = -1;
	public long totalPacketsSent = -1;
	public long totalPacketsReceived = -1;
	public long uptime = -1;

	public UPnPSystemStats() {
		
		
		if ( (UPnPBWStats.getInstance().getMostRecent() != null) ) {
			timeRecorded = UPnPBWStats.getInstance().getMostRecent().timeRecorded;
			numberOfActiveConnections = UPnPBWStats.getInstance().getMostRecent().numberOfActiveConnections;
			totalBytesSent = UPnPBWStats.getInstance().getMostRecent().totalBytesSent;
			totalBytesReceived = UPnPBWStats.getInstance().getMostRecent().totalBytesReceived;
			totalPacketsSent = UPnPBWStats.getInstance().getMostRecent().totalPacketsSent;
			totalPacketsReceived = UPnPBWStats.getInstance().getMostRecent().totalPacketsReceived;
			uptime = UPnPBWStats.getInstance().getMostRecent().uptime;
			
		}

	}
	
     public Object clone() {

    	 try {
              return super.clone();
          }
    	 catch( CloneNotSupportedException e ) {
              return null;
          }
      } 
     
     
     @Override
     public String toString() {
    	 
			return( this.timeRecorded + " " + this.numberOfActiveConnections + " " +
					this.totalBytesSent + " "  + this.totalBytesReceived + " " +
					this.totalPacketsSent + " " + this.totalPacketsReceived + " " + this.uptime);

     }
	
}
